@@ -479,31 +479,34 @@ class SME_Solver:
         nparameters = len(freep_name)
         freep_unc = np.zeros(nparameters)
 
+        # The goodness of fit
+        # but the metric below, is already indifferent to
+        # the absolute scale of the uncertainties
         chi2 = np.sum(resid ** 2) / (resid.size - nparameters)
 
         # Cumulative distribution function of the normal distribution
         # cdf = lambda x, mu, sig: 0.5 * (1 + erf((x - mu) / (np.sqrt(2) * sig)))
         # std = lambda mu, sig: sig
 
-        def cdf(x, mu, alpha):
-            """
-            Cumulative distribution function of the generalized normal distribution
-            the factor sqrt(2) is a conversion between generalized and regular normal distribution
-            """
-            # return gennorm.cdf(x, beta, loc=mu, scale=alpha * np.sqrt(2))
-            return norm.cdf(x, loc=mu, scale=alpha)
+        # def cdf(x, mu, alpha):
+        #     """
+        #     Cumulative distribution function of the generalized normal distribution
+        #     the factor sqrt(2) is a conversion between generalized and regular normal distribution
+        #     """
+        #     # return gennorm.cdf(x, beta, loc=mu, scale=alpha * np.sqrt(2))
+        #     return norm.cdf(x, loc=mu, scale=alpha)
 
-        def std(mu, alpha):
-            """1 sigma (68.27 %) quantile, assuming symmetric distribution"""
-            # interval = gennorm.interval(0.6827, beta, loc=mu, scale=alpha * np.sqrt(2))
-            interval = norm.interval(0.6827, loc=mu, scale=alpha)
-            sigma = (interval[1] - interval[0]) / 2
-            return sigma
+        # def std(mu, alpha):
+        #     """1 sigma (68.27 %) quantile, assuming symmetric distribution"""
+        #     # interval = gennorm.interval(0.6827, beta, loc=mu, scale=alpha * np.sqrt(2))
+        #     interval = norm.interval(0.6827, loc=mu, scale=alpha)
+        #     sigma = (interval[1] - interval[0]) / 2
+        #     return sigma
 
         for i, pname in enumerate(freep_name):
-            pder = deriv[:, i] / np.sqrt(chi2)
+            pder = deriv[:, i]
             idx = pder != 0
-            # idx &= np.abs(resid) < 5 * unc / unc_median
+            idx &= np.abs(resid) / np.sqrt(chi2) < 5
 
             med = np.median(np.abs(pder))
             mad = np.median(np.abs(np.abs(pder) - med))
@@ -511,7 +514,8 @@ class SME_Solver:
 
             if np.count_nonzero(idx) <= 5:
                 logger.warning(
-                    "Not enough data points with a suitable derivative to determine the uncertainties of %s",
+                    "Not enough data points with a suitable derivative "
+                    "to determine the uncertainties of %s",
                     freep_name[i],
                 )
                 continue
@@ -520,7 +524,8 @@ class SME_Solver:
             idx_sort = np.argsort(resid[idx] / pder[idx])
             ch_x = resid[idx][idx_sort] / pder[idx][idx_sort]
             # Weights of the individual pixels also sorted
-            ch_y = np.abs(pder[idx][idx_sort]) / unc[idx][idx_sort]
+            # uncertainties are already included in pder / unc[idx][idx_sort]
+            ch_y = np.abs(pder[idx][idx_sort])
             # Cumulative weights
             ch_y = np.cumsum(ch_y)
             # Normalized cumulative weights
@@ -529,8 +534,11 @@ class SME_Solver:
             hmed = np.interp(0.5, ch_y, ch_x)
             interval = np.interp([0.16, 0.84], ch_y, ch_x)
             sigma_estimate = (interval[1] - interval[0]) / 2
+            freep_unc[i] = sigma_estimate
 
             # # Fit the distribution
+            # from scipy.optimize import curve_fit
+
             # try:
             #     sopt, _ = curve_fit(cdf, ch_x, ch_y)
             # except RuntimeError:
@@ -542,7 +550,6 @@ class SME_Solver:
 
             # hmed = sopt[0]
             # sigma_estimate = std(*sopt)
-            freep_unc[i] = sigma_estimate
 
             # # Debug plots
             # import matplotlib.pyplot as plt
@@ -571,7 +578,7 @@ class SME_Solver:
             # plt.xlim(r)
             # plt.show()
 
-            logger.debug(f"{pname}: {hmed}, {sigma_estimate}")
+            # logger.debug(f"{pname}: {hmed}, {sigma_estimate}")
 
         return freep_unc
 
@@ -594,15 +601,15 @@ class SME_Solver:
         sme.fitresults.gradient = result.grad
         sme.fitresults.derivative = result.jac
         sme.fitresults.residuals = result.fun
-        sme.fitresults.chisq = (
-            result.cost * 2 / (sme.spec.size - len(self.parameter_names))
+        sme.fitresults.chisq = np.sum(result.fun ** 2) / (
+            result.fun.size - len(self.parameter_names)
         )
         sme.fitresults.iterations = self.iteration
 
         sme.fitresults.fit_uncertainties = [np.nan for _ in self.parameter_names]
         for i in range(len(self.parameter_names)):
             # Errors based on covariance matrix
-            sme.fitresults.fit_uncertainties[i] = sig[i]
+            sme.fitresults.fit_uncertainties[i] = sig[i] * np.sqrt(sme.fitresults.chisq)
 
         try:
             mask = sme.mask_good[segments]
@@ -613,6 +620,10 @@ class SME_Solver:
                 unc, result.fun, result.jac
             )
         except:
+            logger.warning(
+                "Could not determine the uncertainties from the probability "
+                "distribution, using fit uncertainties instead"
+            )
             sme.fitresults.uncertainties = sme.fitresults.fit_uncertainties
         # sme.fitresults.uncertainties = sme.fitresults.fit_uncertainties
 
@@ -738,7 +749,7 @@ class SME_Solver:
         # This is the expected range of the uncertainty
         # if the residuals are larger, they are dampened by log(1 + z)
         self.f_scale = 0.2 * np.nanmean(spec.ravel()) / np.nanmean(uncs.ravel())
-        self.f_scale = VariableNumber(self.f_scale)
+        # self.f_scale = VariableNumber(self.f_scale)
 
         # Divide the uncertainties by the spectrum, to improve the fit in the continuum
         # Just as in IDL SME, this increases the relative error for points inside lines
@@ -777,7 +788,7 @@ class SME_Solver:
                     loss="cauchy",
                     f_scale=self.f_scale,
                     method="dogbox",
-                    # x_scale="jac",
+                    # x_scale=step_sizes,
                     # These control the tolerance, for early termination
                     # since each iteration is quite expensive
                     xtol=sme.accxt,
